@@ -6,11 +6,12 @@ use strict qw(vars refs subs);
 use Meta::Baseline::Utils qw();
 
 our($VERSION,@ISA);
-$VERSION="0.17";
+$VERSION="0.20";
 @ISA=qw();
 
 #sub new($);
 #sub create_file($$);
+#sub TEST($);
 
 #__DATA__
 
@@ -26,6 +27,11 @@ sub create_file($$) {
 	Meta::Baseline::Utils::file_emblem($file);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -59,7 +65,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Lang.pm
 	PROJECT: meta
-	VERSION: 0.17
+	VERSION: 0.20
 
 =head1 SYNOPSIS
 
@@ -76,6 +82,7 @@ This is the base class to all language modules.
 
 	new($)
 	create_file($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -89,8 +96,16 @@ This is the constructor.
 
 This method will create a stub template file.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -98,8 +113,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -122,10 +137,13 @@ None.
 	0.15 MV movies and small fixes
 	0.16 MV thumbnail user interface
 	0.17 MV more thumbnail issues
+	0.18 MV website construction
+	0.19 MV web site automation
+	0.20 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Baseline::Utils(3), strict(3)
 
 =head1 TODO
 
