@@ -6,10 +6,11 @@ use strict qw(vars refs subs);
 use Meta::Ds::Graph qw();
 
 our($VERSION,@ISA);
-$VERSION="0.08";
+$VERSION="0.11";
 @ISA=qw(Meta::Ds::Graph);
 
 #sub new($);
+#sub TEST($);
 
 #__DATA__
 
@@ -20,6 +21,11 @@ sub new($) {
 	return($self);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -53,7 +59,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Deps.pm
 	PROJECT: meta
-	VERSION: 0.08
+	VERSION: 0.11
 
 =head1 SYNOPSIS
 
@@ -69,6 +75,7 @@ a project. Currently this is just a Graph.
 =head1 FUNCTIONS
 
 	new($)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -78,8 +85,16 @@ a project. Currently this is just a Graph.
 
 This is a constructor for the Meta::Development::Deps object.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+Meta::Ds::Graph(3)
+
 =head1 BUGS
 
 None.
@@ -87,8 +102,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -102,10 +117,13 @@ None.
 	0.06 MV movies and small fixes
 	0.07 MV thumbnail user interface
 	0.08 MV more thumbnail issues
+	0.09 MV website construction
+	0.10 MV web site automation
+	0.11 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Ds::Graph(3), strict(3)
 
 =head1 TODO
 
