@@ -8,7 +8,7 @@ use Meta::Utils::System qw();
 use Meta::Utils::Output qw();
 
 our($VERSION,@ISA);
-$VERSION="0.31";
+$VERSION="0.34";
 @ISA=qw();
 
 #sub new($);
@@ -21,6 +21,7 @@ $VERSION="0.31";
 #sub print($$);
 #sub sort($$);
 #sub join($$);
+#sub TEST($);
 
 #__DATA__
 
@@ -116,6 +117,11 @@ sub join($$) {
 	return(CORE::join($expr,@$arra));
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -149,7 +155,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Array.pm
 	PROJECT: meta
-	VERSION: 0.31
+	VERSION: 0.34
 
 =head1 SYNOPSIS
 
@@ -182,6 +188,7 @@ This will give you a clean object.
 	print($$)
 	sort($$)
 	join($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -249,8 +256,16 @@ arrya.
 This method will return a string joining the elements of the array
 using a specific expression. This method uses the CORE::join function.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -258,8 +273,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -296,10 +311,13 @@ None.
 	0.29 MV more thumbnail stuff
 	0.30 MV thumbnail user interface
 	0.31 MV more thumbnail issues
+	0.32 MV website construction
+	0.33 MV web site automation
+	0.34 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Utils::Arg(3), Meta::Utils::Output(3), Meta::Utils::System(3), strict(3)
 
 =head1 TODO
 
