@@ -9,7 +9,7 @@ use Meta::Utils::Output qw();
 use Meta::Utils::Arg qw();
 
 our($VERSION,@ISA);
-$VERSION="0.09";
+$VERSION="0.12";
 @ISA=qw();
 
 #sub new($);
@@ -32,6 +32,7 @@ $VERSION="0.09";
 #sub print($$);
 #sub numb_cycl($$$);
 #sub all_ou($$$$);
+#sub TEST($);
 
 #__DATA__
 
@@ -289,6 +290,11 @@ sub all_ou($$$$) {
 	}
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -322,7 +328,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Dgraph.pm
 	PROJECT: meta
-	VERSION: 0.09
+	VERSION: 0.12
 
 =head1 SYNOPSIS
 
@@ -364,6 +370,7 @@ want) on the nodes and edges of the graph.
 	print($$)
 	numb_cycl($$$)
 	all_ou($$$$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -454,8 +461,16 @@ This is also receives the name of the file to be verbose into...
 This method will add the nodes which are outwardly connected (recursivly)
 to the hash given to it.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -463,8 +478,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -479,10 +494,13 @@ None.
 	0.07 MV more thumbnail stuff
 	0.08 MV thumbnail user interface
 	0.09 MV more thumbnail issues
+	0.10 MV website construction
+	0.11 MV web site automation
+	0.12 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Ds::Ohash(3), Meta::Ds::Oset(3), Meta::Utils::Arg(3), Meta::Utils::Output(3), strict(3)
 
 =head1 TODO
 
