@@ -6,7 +6,7 @@ use strict qw(vars refs subs);
 use Meta::Ds::Hash qw();
 
 our($VERSION,@ISA);
-$VERSION="0.31";
+$VERSION="0.34";
 @ISA=qw(Meta::Ds::Hash);
 
 #sub new($);
@@ -17,6 +17,7 @@ $VERSION="0.31";
 #sub valx($$);
 #sub print($$);
 #sub get_elem_number($$);
+#sub TEST($);
 
 #__DATA__
 
@@ -102,6 +103,11 @@ sub get_elem_number($$) {
 	return($self->{OHASH}->{$elem});
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -135,7 +141,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Ohash.pm
 	PROJECT: meta
-	VERSION: 0.31
+	VERSION: 0.34
 
 =head1 SYNOPSIS
 
@@ -157,6 +163,7 @@ element.
 	valx($$)
 	print($$)
 	get_elem_number($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -198,8 +205,16 @@ This will print the Ohash object to the specified file for you.
 
 This method will give you the sequential number of an element in the ordered hash.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+Meta::Ds::Hash(3)
+
 =head1 BUGS
 
 None.
@@ -207,8 +222,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -245,10 +260,13 @@ None.
 	0.29 MV more thumbnail code
 	0.30 MV thumbnail user interface
 	0.31 MV more thumbnail issues
+	0.32 MV website construction
+	0.33 MV web site automation
+	0.34 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Ds::Hash(3), strict(3)
 
 =head1 TODO
 
