@@ -13,7 +13,7 @@ use Meta::Utils::Utils qw();
 use Meta::Baseline::Utils qw();
 
 our($VERSION,@ISA);
-$VERSION="0.11";
+$VERSION="0.14";
 @ISA=qw();
 
 #sub check($);
@@ -26,6 +26,7 @@ $VERSION="0.11";
 #sub c2mifx($);
 #sub c2pdfx($);
 #sub tool($$$);
+#sub TEST($);
 
 #__DATA__
 
@@ -151,6 +152,11 @@ sub tool($$$) {
 	return($scod);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -184,7 +190,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Sgmltoolslite.pm
 	PROJECT: meta
-	VERSION: 0.11
+	VERSION: 0.14
 
 =head1 SYNOPSIS
 
@@ -218,6 +224,7 @@ if it doesnt find openjade).
 	c2mifx($)
 	c2pdfx($)
 	tool($$$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -274,8 +281,16 @@ The problem is that sgmltools does not allow the option to specify the
 output file and so we do all the work using a temporary file and then
 move the result.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -283,8 +298,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -301,10 +316,13 @@ None.
 	0.09 MV movies and small fixes
 	0.10 MV thumbnail user interface
 	0.11 MV more thumbnail issues
+	0.12 MV website construction
+	0.13 MV web site automation
+	0.14 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Baseline::Utils(3), Meta::Utils::File::Copy(3), Meta::Utils::File::Move(3), Meta::Utils::File::Remove(3), Meta::Utils::Output(3), Meta::Utils::System(3), Meta::Utils::Text::Lines(3), Meta::Utils::Utils(3), strict(3)
 
 =head1 TODO
 
