@@ -8,7 +8,7 @@ use Meta::Utils::File::File qw();
 use Meta::Utils::Output qw();
 
 our($VERSION,@ISA);
-$VERSION="0.30";
+$VERSION="0.33";
 @ISA=qw();
 
 #sub size($);
@@ -42,6 +42,8 @@ $VERSION="0.30";
 #sub save($$);
 #sub load($$);
 
+#sub TEST($);
+
 #__DATA__
 
 sub cmp($$$$$) {
@@ -344,6 +346,11 @@ sub load($$) {
 #	Meta::Utils::Arg::check_arg($hash,"HASH");
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -377,7 +384,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Hash.pm
 	PROJECT: meta
-	VERSION: 0.30
+	VERSION: 0.33
 
 =head1 SYNOPSIS
 
@@ -422,6 +429,7 @@ whereever possible.
 	filter_notexists($)
 	save($$)
 	load($$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -588,8 +596,16 @@ This routine saves the entire hash to a disk file.
 
 This routine loads the entire hash from a disk file.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -597,8 +613,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -634,10 +650,13 @@ None.
 	0.28 MV more thumbnail code
 	0.29 MV thumbnail user interface
 	0.30 MV more thumbnail issues
+	0.31 MV website construction
+	0.32 MV web site automation
+	0.33 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Utils::File::File(3), Meta::Utils::Output(3), Meta::Utils::Utils(3), strict(3)
 
 =head1 TODO
 
