@@ -10,7 +10,7 @@ use Meta::Utils::Debug qw();
 use Meta::Utils::Output qw();
 
 our($VERSION,@ISA);
-$VERSION="0.35";
+$VERSION="0.38";
 @ISA=qw();
 
 #sub system_nodie($$);
@@ -30,6 +30,7 @@ $VERSION="0.35";
 #sub os_exit($);
 #sub exit($);
 #sub die($);
+#sub TEST($);
 
 my($eval);
 
@@ -242,6 +243,11 @@ sub die($) {
 	Carp::confess($stri);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -275,7 +281,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: System.pm
 	PROJECT: meta
-	VERSION: 0.35
+	VERSION: 0.38
 
 =head1 SYNOPSIS
 
@@ -314,6 +320,7 @@ die on errors from the execution process...
 	os_exit($)
 	exit($)
 	die($)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -452,8 +459,16 @@ it. This means that you pass 1 for success and 0 otherwise.
 
 This routine gets a string and dies while printing the string.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+None.
+
 =head1 BUGS
 
 None.
@@ -461,8 +476,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -503,10 +518,13 @@ None.
 	0.33 MV thumbnail user interface
 	0.34 MV more thumbnail issues
 	0.35 MV md5 project
+	0.36 MV website construction
+	0.37 MV web site automation
+	0.38 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Carp(3), Meta::Utils::Debug(3), Meta::Utils::File::File(3), Meta::Utils::Output(3), Meta::Utils::Utils(3), strict(3)
 
 =head1 TODO
 
