@@ -9,11 +9,12 @@ use Meta::Baseline::Aegis qw();
 use Meta::Utils::File::File qw();
 
 our($VERSION,@ISA);
-$VERSION="0.06";
+$VERSION="0.09";
 @ISA=qw(XML::Checker::Parser);
 
 #sub new($);
 #sub handle_externent($$$$);
+#sub TEST($);
 
 #__DATA__
 
@@ -41,6 +42,11 @@ sub handle_externent($$$$) {
 	return($data);
 }
 
+sub TEST($) {
+	my($context)=@_;
+	return(1);
+}
+
 1;
 
 __END__
@@ -74,7 +80,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 
 	MANIFEST: Checker.pm
 	PROJECT: meta
-	VERSION: 0.06
+	VERSION: 0.09
 
 =head1 SYNOPSIS
 
@@ -96,6 +102,7 @@ which is derived here over the regular checker.
 
 	new($)
 	handle_externent($$$$)
+	TEST($)
 
 =head1 FUNCTION DOCUMENTATION
 
@@ -109,8 +116,16 @@ This gives you a new object for a parser.
 
 This method will handle resolving external references.
 
+=item B<TEST($)>
+
+Test suite for this module.
+
 =back
 
+=head1 SUPER CLASSES
+
+XML::Checker::Parser(3)
+
 =head1 BUGS
 
 None.
@@ -118,8 +133,8 @@ None.
 =head1 AUTHOR
 
 	Name: Mark Veltzer
-	Email: mark2776@yahoo.com
-	WWW: http://www.geocities.com/mark2776
+	Email: mailto:veltzer@cpan.org
+	WWW: http://www.veltzer.org
 	CPAN id: VELTZER
 
 =head1 HISTORY
@@ -131,10 +146,13 @@ None.
 	0.04 MV movies and small fixes
 	0.05 MV thumbnail user interface
 	0.06 MV more thumbnail issues
+	0.07 MV website construction
+	0.08 MV web site automation
+	0.09 MV SEE ALSO section fix
 
 =head1 SEE ALSO
 
-Nothing.
+Meta::Baseline::Aegis(3), Meta::Utils::File::File(3), Meta::Utils::Output(3), XML::Checker::Parser(3), strict(3)
 
 =head1 TODO
 
